abacusai.document_annotation — AbacusAI documentation

# `abacusai.document_annotation`

## Module Contents

### Classes

`DocumentAnnotation` | An annotation for a document in a document store

class abacusai.document_annotation.DocumentAnnotation(client, annotation=None, boundingBox=None, createdAt=None, count=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An annotation for a document in a document store

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - annotation (str) – The name of the annotation

    - boundingBox (dict) – The bounding box for this annotation

    - createdAt (str) – The timestamp at which the annotation was first used

    - count (int) – The number of this annotation used in the document store

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict